﻿function Get-ImportInfo
{
    [CmdletBinding(SupportsShouldProcess=$true, 
                  PositionalBinding=$false,
                  ConfirmImpact='Medium')]
    [Alias()]
    [OutputType([PSOBJECT])]

    param (
        [Parameter(Mandatory=$True, ParameterSetName='ELHC')]
        [ValidateNotNullOrEmpty()]
        [PSObject]$ELHCConfig = $false,

        [Parameter(Mandatory=$False, ParameterSetName='External')]
        [ValidateNotNullOrEmpty()]
        [string]$ConnectionString = "data source=(local);initial catalog=WGEvidenceLibrary;integrated security=true;connection lifetime=30;"
    )

    if($ELHCConfig) {
        $ConnectionString = $ELHCConfig.root.ConnectionString
        $AlertDays = ([int]$ELHCConfig.root.components.standalone.component.ImportInfo.alerts.AllowedDays)
    }

    $WGEvidenceLibraryImport = . {
        $LastImportDateQuery = (
        "select top 1 Imported
        from dbo.RecordingEvent
        where SubstationID = '$($ELHCConfig.root.substationID)'
        Group by Imported
        Order by max(imported) desc;"
    )
        $LastImportDate = (Get-QueryResult -query $LastImportDateQuery -connectionstring $ConnectionString).Imported

    $HoursSinceImportedQuery = (
        "select top 1 DateDiff(HOUR, Imported, GETUTCDATE()) as HoursSinceImport
        from dbo.RecordingEvent
        where SubstationID = '$($ELHCConfig.root.substationID)'
        Group by Imported
        Order by max(imported) desc;"
    )
        $HoursSinceImported = (Get-queryresult -query $HoursSinceImportedQuery -connectionstring $ConnectionString).HoursSinceImport
        $DaysSinceImported = [math]::Round(($HoursSinceImported / 24),2)
    }

    $AlertBool = $false
    if ($DaysSinceImported -gt $AlertDays) {
        $AlertBool = $true
    }

    $Results = @{
        'LogType' = "ImportInfo"
        'LastImportDate' = $LastImportDate
        'HoursSinceImported' = $HoursSinceImported
        'DaysSinceImported' = $DaysSinceImported
        'AlertDaysSinceImport' = $AlertDays
        'AlertBool' = $AlertBool
    }

    return $Results
}